class Tester:
    def __init__(self, solution):
        self.solution = solution

    def handle(self, inp, out, ans=None, verdict=None, checker_log=None):
        print("exit code:", out[2])
        if verdict is not None:
            print("verdict:", verdict)
        print()

        print("Input")
        print(inp)

        print("Output")
        print(out[0])

        if out[1]:
            print("Error")
            print(out[1])

        if ans is not None:
            print("Answer")
            print(ans)

        if checker_log is not None:
            print("Checker Log")
            print(checker_log)

        print("-" * 80)

    def run_testcases(self, testcases):
        for testcase in testcases:
            out = self.solution(testcase[0])

            if out[2]:
                verdict = "RUNTIME ERROR"
            elif out[0] == testcase[1]:
                verdict = "OK"
            else:
                verdict = "WRONG ANSWER"

            self.handle(testcase[0], out, testcase[1], verdict)

    def run_inputs(self, inputs, checker=None):
        checker = (lambda inp, out: (None, None)) if checker is None else checker

        for inp in inputs:
            out = self.solution(inp)

            if out[2]:
                verdict = "RUNTIME ERROR"
            else:
                verdict, checker_log = checker(inp, out[0])

            self.handle(inp, out, verdict=verdict, checker_log=checker_log)



import sys
import traceback

if sys.version_info[0] >= 3:
    from io import StringIO as stream
else:
    from io import BytesIO as stream


def sol2func(func):
    def new_func(inp):
        old_stdin = sys.stdin
        old_stdout = sys.stdout
        old_stderr = sys.stderr

        sys.stdin = stream(inp)
        sys.stdout = stream()
        sys.stderr = stream()

        try:
            exit_code = func() or 0
        except SystemExit as e:
            exit_code = e.code
        except Exception:
            traceback.print_exc()
            exit_code = 1
        finally:
            out = sys.stdout.getvalue()
            err = sys.stderr.getvalue()

            sys.stdin = old_stdin
            sys.stdout = old_stdout
            sys.stderr = old_stderr

        return out, err, exit_code

    return new_func
